/********************************************************************\

  Name:         experim.h
  Created by:   ODBedit program

  Contents:     This file contains C structures for the "Experiment"
                tree in the ODB and the "/Analyzer/Parameters" tree.

                Additionally, it contains the "Settings" subtree for
                all items listed under "/Equipment" as well as their
                event definition.

                It can be used by the frontend and analyzer to work
                with these information.

                All C structures are accompanied with a string represen-
                tation which can be used in the db_create_record function
                to setup an ODB structure which matches the C structure.

  Created on:   Tue Oct 31 06:51:00 2000

\********************************************************************/

#define EXP_PARAM_DEFINED

typedef struct {
  char      magnet_field[32];
  float     beam_momentum;
  char      gas_mixture[32];
  char      chamber_voltages[32];
  char      comment[80];
} EXP_PARAM;

#define EXP_PARAM_STR(_name) char *_name[] = {\
"[.]",\
"Magnet field = STRING : [32] On -2740DAC",\
"Beam momentum = FLOAT : 216",\
"Gas mixture = STRING : [32] 50% He, 50% Ethane",\
"Chamber voltages = STRING : [32] 2000,1500,1500",\
"Comment = STRING : [80] trigger S0,S1,S2",\
"",\
NULL }

#define EXP_EDIT_DEFINED

typedef struct {
  char      magnet_field[32];
  float     beam_momentum;
  char      gas_mixture[32];
  char      chamber_voltages[32];
  BOOL      write_data;
  char      comment[80];
} EXP_EDIT;

#define EXP_EDIT_STR(_name) char *_name[] = {\
"[.]",\
"Magnet field = LINK : [40] /Experiment/Run Parameters/Magnet field",\
"Beam momentum = LINK : [41] /Experiment/Run Parameters/Beam momentum",\
"Gas mixture = LINK : [39] /Experiment/Run Parameters/Gas mixture",\
"Chamber voltages = LINK : [44] /Experiment/Run Parameters/Chamber voltages",\
"Write data = LINK : [19] /Logger/Write data",\
"Comment = LINK : [35] /Experiment/Run Parameters/Comment",\
"",\
NULL }

#ifndef EXCL_ADC_CALIBRATION

#define ADC_CALIBRATION_PARAM_DEFINED

typedef struct {
  INT       pedestal[54];
  float     software_gain[54];
  double    histo_threshold;
} ADC_CALIBRATION_PARAM;

#define ADC_CALIBRATION_PARAM_STR(_name) char *_name[] = {\
"[.]",\
"Pedestal = INT[54] :",\
"[0] 34",\
"[1] 37",\
"[2] 36",\
"[3] 30",\
"[4] 36",\
"[5] 30",\
"[6] 40",\
"[7] 29",\
"[8] 0",\
"[9] 0",\
"[10] 0",\
"[11] 0",\
"[12] 0",\
"[13] 0",\
"[14] 0",\
"[15] 0",\
"[16] 0",\
"[17] 28",\
"[18] 30",\
"[19] 25",\
"[20] 20",\
"[21] 30",\
"[22] 20",\
"[23] 30",\
"[24] 43",\
"[25] 30",\
"[26] 30",\
"[27] 30",\
"[28] 30",\
"[29] 50",\
"[30] 50",\
"[31] 50",\
"[32] 50",\
"[33] 52",\
"[34] 50",\
"[35] 52",\
"[36] 40",\
"[37] 0",\
"[38] 35",\
"[39] 35",\
"[40] 38",\
"[41] 41",\
"[42] 44",\
"[43] 40",\
"[44] 40",\
"[45] 40",\
"[46] 40",\
"[47] 42",\
"[48] 0",\
"[49] 0",\
"[50] 0",\
"[51] 0",\
"[52] 0",\
"[53] 0",\
"Software Gain = FLOAT[54] :",\
"[0] 1",\
"[1] 1",\
"[2] 1",\
"[3] 1",\
"[4] 1",\
"[5] 1",\
"[6] 1",\
"[7] 1",\
"[8] 1",\
"[9] 1",\
"[10] 1",\
"[11] 1",\
"[12] 1",\
"[13] 1",\
"[14] 1",\
"[15] 1",\
"[16] 1",\
"[17] 1",\
"[18] 1",\
"[19] 1",\
"[20] 1",\
"[21] 1",\
"[22] 1",\
"[23] 1",\
"[24] 1",\
"[25] 1",\
"[26] 1",\
"[27] 1",\
"[28] 1",\
"[29] 1",\
"[30] 1",\
"[31] 1",\
"[32] 1",\
"[33] 1",\
"[34] 1",\
"[35] 1",\
"[36] 1",\
"[37] 1",\
"[38] 1",\
"[39] 1",\
"[40] 1",\
"[41] 1",\
"[42] 1",\
"[43] 1",\
"[44] 1",\
"[45] 1",\
"[46] 1",\
"[47] 1",\
"[48] 1",\
"[49] 1",\
"[50] 1",\
"[51] 1",\
"[52] 1",\
"[53] 1",\
"Histo threshold = DOUBLE : -100",\
"",\
NULL }

#endif

#ifndef EXCL_GLOBAL

#define GLOBAL_PARAM_DEFINED

typedef struct {
  float     adc_threshold;
} GLOBAL_PARAM;

#define GLOBAL_PARAM_STR(_name) char *_name[] = {\
"[.]",\
"ADC Threshold = FLOAT : 5",\
"",\
NULL }

#endif

#ifndef EXCL_TDC_CALIBRATION

#define TDC_CALIBRATION_PARAM_DEFINED

typedef struct {
  float     ns_per_bin;
  INT       offset[24];
} TDC_CALIBRATION_PARAM;

#define TDC_CALIBRATION_PARAM_STR(_name) char *_name[] = {\
"[.]",\
"ns per bin = FLOAT : 0.05",\
"Offset = INT[24] :",\
"[0] 75",\
"[1] 75",\
"[2] 75",\
"[3] 75",\
"[4] 75",\
"[5] 75",\
"[6] 75",\
"[7] 75",\
"[8] 0",\
"[9] 0",\
"[10] 0",\
"[11] 0",\
"[12] 0",\
"[13] 0",\
"[14] 0",\
"[15] 0",\
"[16] 23",\
"[17] 13",\
"[18] 15",\
"[19] 15",\
"[20] 0",\
"[21] 0",\
"[22] 0",\
"[23] 0",\
"",\
NULL }

#endif

#ifndef EXCL_DSC

#define DSC_PARAM_DEFINED

typedef struct {
  float     ns_per_bin[16];
  float     tdc_offset[16];
  float     adc_gain[16];
} DSC_PARAM;

#define DSC_PARAM_STR(_name) char *_name[] = {\
"[.]",\
"ns per bin = FLOAT[16] :",\
"[0] 0",\
"[1] 0",\
"[2] 0",\
"[3] 0",\
"[4] 0",\
"[5] 0",\
"[6] 0",\
"[7] 0",\
"[8] 0",\
"[9] 0",\
"[10] 0",\
"[11] 0",\
"[12] 0",\
"[13] 0",\
"[14] 0",\
"[15] 0",\
"tdc offset = FLOAT[16] :",\
"[0] 0",\
"[1] 0",\
"[2] 0",\
"[3] 0",\
"[4] 0",\
"[5] 0",\
"[6] 0",\
"[7] 0",\
"[8] 0",\
"[9] 0",\
"[10] 0",\
"[11] 0",\
"[12] 0",\
"[13] 0",\
"[14] 0",\
"[15] 0",\
"ADC gain = FLOAT[16] :",\
"[0] 1",\
"[1] 1",\
"[2] 1",\
"[3] 1",\
"[4] 1",\
"[5] 1",\
"[6] 1",\
"[7] 1",\
"[8] 1",\
"[9] 1",\
"[10] 1",\
"[11] 1",\
"[12] 1",\
"[13] 1",\
"[14] 1",\
"[15] 1",\
"",\
NULL }

#endif

#ifndef EXCL_HISTO

#define HISTO_PARAM_DEFINED

typedef struct {
  double    histo_threshold;
} HISTO_PARAM;

#define HISTO_PARAM_STR(_name) char *_name[] = {\
"[.]",\
"Histo threshold = DOUBLE : -100",\
"",\
NULL }

#endif

#ifndef EXCL_GENERAL_HISTO

#define GENERAL_HISTO_PARAM_DEFINED

typedef struct {
  double    histo_threshold;
} GENERAL_HISTO_PARAM;

#define GENERAL_HISTO_PARAM_STR(_name) char *_name[] = {\
"[.]",\
"Histo threshold = DOUBLE : 110",\
"",\
NULL }

#endif

#ifndef EXCL_TRIGGER

#define PCOS_BANK_DEFINED

typedef struct {
  float     ax;
  float     ay;
  float     bx;
  float     by;
} PCOS_BANK;

#define PCOS_BANK_STR(_name) char *_name[] = {\
"[.]",\
"ax = FLOAT : -1000",\
"ay = FLOAT : 54",\
"bx = FLOAT : -1000",\
"by = FLOAT : -1000",\
"",\
NULL }

#define WIRE_BANK_DEFINED

typedef struct {
  float     w1_sum;
  float     w2_sum;
  float     w3_sum;
  float     w4_sum;
} WIRE_BANK;

#define WIRE_BANK_STR(_name) char *_name[] = {\
"[.]",\
"w1_sum = FLOAT : 848",\
"w2_sum = FLOAT : -65",\
"w3_sum = FLOAT : -74",\
"w4_sum = FLOAT : -57",\
"",\
NULL }

#define STRP_BANK_DEFINED

typedef struct {
  float     s1;
  float     s2;
  float     s3;
  float     s4;
  float     s5;
  float     s6;
  float     s7;
  float     s8;
  float     s9;
  float     s10;
  float     s11;
  float     s12;
} STRP_BANK;

#define STRP_BANK_STR(_name) char *_name[] = {\
"[.]",\
"s1 = FLOAT : 0",\
"s2 = FLOAT : 0",\
"s3 = FLOAT : 0",\
"s4 = FLOAT : 0",\
"s5 = FLOAT : 0",\
"s6 = FLOAT : 0",\
"s7 = FLOAT : 0",\
"s8 = FLOAT : 0",\
"s9 = FLOAT : 0",\
"s10 = FLOAT : 0",\
"s11 = FLOAT : 0",\
"s12 = FLOAT : 0",\
"",\
NULL }

#define TRIGGER_COMMON_DEFINED

#define TRIGGER_COMMON_STR(_name) char *_name[] = {\
"[.]",\
"Event ID = WORD : 1",\
"Trigger mask = WORD : 0",\
"Buffer = STRING : [32] SYSTEM",\
"Type = INT : 2",\
"Source = INT : 16777215",\
"Format = STRING : [8] MIDAS",\
"Enabled = BOOL : y",\
"Read on = INT : 257",\
"Period = INT : 500",\
"Event limit = DOUBLE : 500000",\
"Num subevents = DWORD : 0",\
"Log history = INT : 0",\
"Frontend host = STRING : [32] pc2773",\
"Frontend name = STRING : [32] FAL",\
"Frontend file name = STRING : [256] E:\online\frontend.c",\
"",\
NULL }

#define TRIGGER_SETTINGS_DEFINED

typedef struct {
  struct {
    WORD      slot[8];
    WORD      plane[8];
    float     threshold[8];
    WORD      delay[8];
    WORD      n_wires[4];
    float     wire_spacing[4];
    BOOL      mirror[4];
  } pcos;
} TRIGGER_SETTINGS;

#define TRIGGER_SETTINGS_STR(_name) char *_name[] = {\
"[PCOS]",\
"Slot = WORD[8] :",\
"[0] 1",\
"[1] 2",\
"[2] 6",\
"[3] 7",\
"[4] 11",\
"[5] 12",\
"[6] 16",\
"[7] 17",\
"Plane = WORD[8] :",\
"[0] 0",\
"[1] 0",\
"[2] 1",\
"[3] 1",\
"[4] 2",\
"[5] 2",\
"[6] 3",\
"[7] 3",\
"Threshold = FLOAT[8] :",\
"[0] 4",\
"[1] 4",\
"[2] 4",\
"[3] 4",\
"[4] 4",\
"[5] 4",\
"[6] 4",\
"[7] 4",\
"Delay = WORD[8] :",\
"[0] 550",\
"[1] 550",\
"[2] 550",\
"[3] 550",\
"[4] 550",\
"[5] 550",\
"[6] 550",\
"[7] 550",\
"N Wires = WORD[4] :",\
"[0] 64",\
"[1] 64",\
"[2] 64",\
"[3] 64",\
"Wire spacing = FLOAT[4] :",\
"[0] 2",\
"[1] 2",\
"[2] 2",\
"[3] 2",\
"Mirror = BOOL[4] :",\
"[0] n",\
"[1] n",\
"[2] n",\
"[3] n",\
"",\
NULL }

#endif

#ifndef EXCL_SCALER

#define SCALER_COMMON_DEFINED

#define SCALER_COMMON_STR(_name) char *_name[] = {\
"[.]",\
"Event ID = WORD : 2",\
"Trigger mask = WORD : 0",\
"Buffer = STRING : [32] SYSTEM",\
"Type = INT : 1",\
"Source = INT : 0",\
"Format = STRING : [8] MIDAS",\
"Enabled = BOOL : y",\
"Read on = INT : 377",\
"Period = INT : 10000",\
"Event limit = DOUBLE : 0",\
"Num subevents = DWORD : 0",\
"Log history = INT : 0",\
"Frontend host = STRING : [32] pc2773",\
"Frontend name = STRING : [32] FAL",\
"Frontend file name = STRING : [256] E:\online\frontend.c",\
"",\
NULL }

#endif

#ifndef EXCL_HV

#define HV_COMMON_DEFINED

#define HV_COMMON_STR(_name) char *_name[] = {\
"[.]",\
"Event ID = WORD : 3",\
"Trigger mask = WORD : 0",\
"Buffer = STRING : [32] SYSTEM",\
"Type = INT : 8",\
"Source = INT : 0",\
"Format = STRING : [8] MIDAS",\
"Enabled = BOOL : y",\
"Read on = INT : 121",\
"Period = INT : 60000",\
"Event limit = DOUBLE : 1000",\
"Num subevents = DWORD : 0",\
"Log history = INT : 1",\
"Frontend host = STRING : [32] pc2773",\
"Frontend name = STRING : [32] FAL",\
"Frontend file name = STRING : [256] E:\online\frontend.c",\
"",\
NULL }

#define HV_SETTINGS_DEFINED

typedef struct {
  struct {
    INT       hv;
    INT       nitronic;
  } channels;
  char      names[4][32];
  float     update_threshold_measured[4];
  float     update_threshold_current[4];
  float     voltage_limit[4];
  float     current_limit[4];
  float     ramping_speed[4];
  struct {
    struct {
      char      rs232_port[32];
      INT       address;
    } nitronic;
  } devices;
} HV_SETTINGS;

#define HV_SETTINGS_STR(_name) char *_name[] = {\
"[Channels]",\
"HV = INT : 4",\
"Nitronic = INT : 4",\
"",\
"[.]",\
"Names = STRING[4] :",\
"[32] Default%S0",\
"[32] Default%S1",\
"[32] Default%S2",\
"[32] Default%Spare",\
"Update Threshold Measured = FLOAT[4] :",\
"[0] 2",\
"[1] 2",\
"[2] 2",\
"[3] 2",\
"Update Threshold Current = FLOAT[4] :",\
"[0] 2",\
"[1] 2",\
"[2] 2",\
"[3] 2",\
"Voltage Limit = FLOAT[4] :",\
"[0] 3000",\
"[1] 3000",\
"[2] 3000",\
"[3] 3000",\
"Current Limit = FLOAT[4] :",\
"[0] 3000",\
"[1] 3000",\
"[2] 3000",\
"[3] 3000",\
"Ramping Speed = FLOAT[4] :",\
"[0] 0",\
"[1] 0",\
"[2] 0",\
"[3] 0",\
"",\
"[Devices/Nitronic]",\
"RS232 Port = STRING : [32] com1",\
"Address = INT : 0",\
"",\
NULL }

#endif

