/********************************************************************\

  Name:         tdccalib.c
  Created by:   Stefan Ritt

  Contents:     Example analyzer module for TDC calibration.

  $Log$
\********************************************************************/
                                                        
/*-- Include files -------------------------------------------------*/

/* standard includes */
#include <stdio.h>
#include <math.h>

/* midas includes */
#include "midas.h"
#include "experim.h"
#include "analyzer.h"

/* cernlib includes */
#ifdef OS_WINNT
#define VISUAL_CPLUSPLUS
#endif

#ifdef __linux__
#define f2cFortran
#endif

#include <cfortran.h>
#include <hbook.h>

#ifndef PI
#define PI 3.14159265359
#endif

/*-- Parameters ----------------------------------------------------*/

TDC_CALIBRATION_PARAM tdccalib_param;

/*-- Module declaration --------------------------------------------*/

INT tdc_calib(EVENT_HEADER*,void*);
INT tdc_calib_init(void);
INT tdc_calib_bor(INT run_number);

TDC_CALIBRATION_PARAM_STR(tdc_calib_param_str);

ANA_MODULE tdc_calib_module = {
  "TDC calibration",             /* module name           */  
  "Stefan Ritt",                 /* author                */
  tdc_calib,                     /* event routine         */
  NULL,                          /* BOR routine           */
  NULL,                          /* EOR routine           */
  tdc_calib_init,                /* init routine          */
  NULL,                          /* exit routine          */
  &tdccalib_param,               /* parameter structure   */
  sizeof(tdccalib_param),        /* structure size        */
  tdc_calib_param_str,           /* initial parameters    */
};

/*-- init routine --------------------------------------------------*/

char *tdc_tag[] = {
  "WP1_1L", /* TDC1, slot 15 */
  "WP1_2L",
  "WP1_3L",
  "WP1_4L",
  "WP1_1R",
  "WP1_2R",
  "WP1_3R",
  "WP1_4R",

  "WP2_1L", /* TDC2, slot 16 */
  "WP2_2L",
  "WP2_3L",
  "WP2_4L",
  "WP2_1R",
  "WP2_2R",
  "WP2_3R",
  "WP2_4R",

  "RF",  /* TDC3, slot 17 */
  "S0",
  "S1",
  "S2",
  "Spare1",
  "Spare2",
  "Spare3",
  "Spare4",

};

INT tdc_calib_init(void)
{
int  i;
char str[80];

  /* book TDC calib histo */
  for (i=0 ; i<8 ; i++)
    {
    strcpy(str, "TDC ");
    strcat(str, tdc_tag[i]);
    HBOOK1(TDCCALIB_ID_BASE+i, str, 4096, -500.125f, 523.875f, 0.f); 
    }

  for (; i<N_TDC ; i++)
    {
    strcpy(str, "TDC ");
    strcat(str, tdc_tag[i]);
    HBOOK1(TDCCALIB_ID_BASE+i, str, 4096, -100.025f, 104.775f, 0.f); 
    }

  return SUCCESS;
}

/*-- event routine -------------------------------------------------*/

INT tdc_calib(EVENT_HEADER *pheader, void *pevent)
{
INT          i, n_tdc;
WORD         *tdc0;
float        *ctdc;

  /* look for TDC0 bank, return if not present */
  n_tdc = bk_locate(pevent, "TDC0", &tdc0);
  if (n_tdc == 0)
    return ANA_CONTINUE;

  /* create CTDC bank */
  bk_create(pevent, "CTDC", TID_FLOAT, &ctdc);

  /* sum all channels above threshold */
  for (i=0 ; i<8 ; i++)
    ctdc[i] = tdc0[i]*0.25f-tdccalib_param.offset[i];

  for (; i<n_tdc ; i++)
    ctdc[i] = tdc0[i]*0.05f-tdccalib_param.offset[i];

  /* fill TDC histo */
  for (i=0 ; i<n_tdc ; i++)
    HF1(TDCCALIB_ID_BASE+i, ctdc[i], 1.f);

  /* close calculated bank */
  bk_close(pevent, ctdc+n_tdc);
  
  return SUCCESS;
}
